x11_hashw (v1.7)
===========================

Python module for Dash's X11 hashing.


Install
-------

Python 2.7 is required as well as gcc.

    $ python setup.py install


Test
-------

After installation, test hash.

    $ python test.py

Credits
-------

* Module written by @chaeplin https://github.com/chaeplin/xcoin-hash
* Module maintained by @eduffield https://github.com/darkcoinproject/xcoin-hash
* Module maintained by @flare https://github.com/nightlydarkcoin/xcoin-hash
* Module maintained by @vertoe https://github.com/vertoe/darkcoin_hash
* Module maintained by @jakehaas https://github.com/jakehaas/x11_hash
